========
Feedback
========

Feedback on Coiled is always welcome and encouraged. If you have any
comments, questions, or other feedback, please
`open an issue <https://github.com/coiled/coiled-issues/issues/new>`_ in the
Coiled issue tracker on GitHub.

.. link-button:: https://github.com/coiled/coiled-issues/issues/new
    :type: url
    :text: Report an issue
    :classes: btn-outline-primary btn-block


Thank you for trying out Coiled!
